GoRouterDerivation class

Constructors

GoRouterDerivation()

Properties

builderClassToScreen Map<String, String>
Widget-Klasse (aus builder:/pageBuilder:) -> Screen-Id.
final
edges List<GraphEdge>
final
flows List<GraphFlow>
final
hashCode int
The hash code for this object.
no setterinherited
nameToScreen Map<String, String>
final
nodes List<GraphNode>
final
pathToScreen Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited