GraphEdge class

Transition (SPEC 6.3). id ist bis zur Id-Generierung im Merger optional.

Constructors

GraphEdge({String? id, required String from, required String to, String? trigger, String? label, String? condition, required String source, required SourceRef sourceRef})
const

Properties

condition String?
final
from String
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
sourceRef SourceRef
final
to String
final
trigger String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited