GraphFlow class

Benannter Flow (SPEC 6.4). source/sourceRef sind nur intern für die Merge-Präzedenz relevant und werden nicht serialisiert.

Constructors

GraphFlow({required String id, String? title, String? start, String? description, required String source, required SourceRef sourceRef})
const

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
sourceRef SourceRef
final
start String?
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited