GraphNode class

Screen- oder Decision-Node (der Dart-Adapter emittiert keine Action-Nodes, DD B.2).

Constructors

GraphNode({required String id, required String type, String? title, String? flow, String? description, List<String> tags = const [], required String source, required SourceRef sourceRef})
const

Properties

description String?
final
flow String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
sourceRef SourceRef
final
tags List<String>
final
title String?
final
type String
final

Methods

copyWith({String? flow}) GraphNode
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited