MergeResult class

Constructors

MergeResult({required List<GraphNode> nodes, required List<GraphEdge> edges, required List<GraphFlow> flows})
const

Properties

edges List<GraphEdge>
final
flows List<GraphFlow>
final
hashCode int
The hash code for this object.
no setterinherited
nodes List<GraphNode>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited