ScannedFile class

Eine geparste Quelldatei. relPath ist projekt-relativ mit '/'-Separatoren und dient überall als deterministischer Sortierschlüssel.

Constructors

ScannedFile({required String relPath, required String content, required CompilationUnit unit, required LineInfo lineInfo})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
lineInfo → LineInfo
final
relPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unit → CompilationUnit
final

Methods

lineOf(int offset) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refAt(int offset, {String? symbol}) SourceRef
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited