ActionCandidate class
Eine @journey:action / @JourneyAction, deren from ggf. erst nach dem
Scan aller Dateien über die umschließende Klasse aufgelöst wird (DD B.3).
Constructors
Properties
- condition → String?
-
final
- enclosingClassName → String?
-
Name der umschließenden Klasse (für die from-Inferenz), falls vorhanden.
final
- from → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceRef → SourceRef
-
final
- to → String
-
final
- trigger → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited