AutoRouteDerivation class

Constructors

AutoRouteDerivation()

Properties

classToScreen Map<String, String>
Widget-Klasse -> Screen-Id (für die from-Zuordnung von Navigations-Kanten).
final
hashCode int
The hash code for this object.
no setterinherited
nodes List<GraphNode>
final
pathToScreen Map<String, String>
Routen-Pfad -> Screen-Id (aus AutoRoute(page:, path:)-Einträgen).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited