ManualExtraction class
Ergebnis eines manuellen Eingabewegs für eine Datei.
Constructors
Properties
-
actions
→ List<
ActionCandidate> -
final
-
flows
→ List<
GraphFlow> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nodes
→ List<
GraphNode> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
screenClassNames
→ Map<
String, String> -
Klassenname -> Screen-Id (für from-Inferenz und context.go-Zuordnung).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited